@@ -10,14 +10,18 @@ from pathlib import Path
 
 class CommonData(InputData):
     # waste Materials
-    WasteMaterials = ['CompFeed', 'ComRes', 'CompFin', 'Digestate',
+    WasteMaterials = ['CompFeed', 'CompRes', 'CompFin', 'Digestate',
                       'MSW', 'C&DWaste', 'MedWaste', 'MRFRes', 'CombRes',
-                      'ContamSoil',
-                      'ContactWater', 'LF_Leachate',
+                      'ContaminatedSoil',
+                      'ContactWater', 'LFLeachate', 'ContaminatedWater',
                       'DewWWTSol', 'DryWWTSol', 'WWTSol',
                       'SCWO_Steam', 'SCWO_Slurry',
                       'SpentGAC', 'ROConc']
 
+    # PFAS Index
+    PFAS_Index = ['Summed PFAS', 'PFOA', 'PFOS', 'PFAS#4', 'PFAS#5', 'PFAS#6',
+                  'PFAS#7', 'PFAS#8', 'PFAS#9', 'PFAS#10']
+
     def __init__(self, input_data_path=None):
         if input_data_path:
             self.input_data_path = input_data_path
