@@ -65,6 +65,10 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
         ### Menu
         self.actionHelp_Gui.triggered.connect(self.Help_Gui_func)
 
+        # Icon
+        self.icon = QtGui.QIcon()
+        self.icon.addPixmap(QtGui.QPixmap(":/icons/ICONS/PFAS_SAT_1.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+
     def init_app(self):
         self.PFAS_SAT_1.setCurrentWidget(self.Start_tab)
         
@@ -157,13 +161,13 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
                             'MRFRes': self.MRFRes,
                             'CombRes': self.CombRes,
                             'AutoShredRes': self.AutoShredRes,
-                            'ContamWater': self.ContWater,
-                            'ContamSoil': self.ContSoil,
+                            'ContaminatedWater': self.ContWater,
+                            'ContaminatedSoil': self.ContSoil,
                             'DewWWTSol': self.DewWWTSol,
                             'DryWWTSol': self.DryWWTSol,
                             'WWTSol': self.WWTSol,
                             'ROConc': self.ROC,
-                            'LF_Leachate': self.LFLeach,
+                            'LFLeachate': self.LFLeach,
                             'ContactWater': self.ContactWater,
                             'Solidi_Waste': self.Solidi_Waste,
                             'SpentGAC': self.SGAC,
@@ -623,7 +627,7 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
         elif Type == 'Information':
             msg.setIcon(msg.Icon.Information)
         msg.setWindowTitle('PFAS SAT')
-        #msg.setWindowIcon(self.icon)
+        msg.setWindowIcon(self.icon)
         msg.setText(Subject)
         msg.setInformativeText(Information)
         Ok=msg.addButton(msg.Ok)
