@@ -5,14 +5,17 @@ Created on Fri Jul 24 11:48:31 2020
 @author: msmsa
 """
 from .Flow import Flow
-from .CommonData import CommonData
 from .IncomFlowInput import IncomFlowInput
 
 
 class IncomFlow():
     def __init__(self, input_data_path=None):
         self.InputData = IncomFlowInput(input_data_path)
-        self.WasteMaterials = CommonData.WasteMaterials
+        wasteMaterils = self.InputData.Data['Dictonary_Name'].unique()
+        self.WasteMaterials = []
+        for i in wasteMaterils:
+            if 'PFAS' not in i:
+                self.WasteMaterials.append(i)
 
     def set_flow(self, flow_name, mass_flow):
         self._flow_name = flow_name
