@@ -5,11 +5,12 @@ Created on Mon Jul 27 22:09:10 2020
 @author: msmsa
 """
 import pandas as pd
+from .CommonData import CommonData
 
 
 class Inventory:
     def __init__(self):
-        self._PFAS_Index = ['PFAS', 'PFOA', 'PFNA', 'PFDA', 'PFUnA', 'PFOS', 'PFDS', 'N_MeFOSAA', 'N_EtFOSAA']
+        self._PFAS_Index = CommonData.PFAS_Index
         self._index = ['Flow_name', 'Source', 'Target', 'Unit'] + self._PFAS_Index
         self.Inv = pd.DataFrame(index=self._index)
         self.Col_index = 0
